import inspect
import uuid
from time import sleep
try:
    from pyCryptomusAPI import pyCryptomusAPI, pyCryptomusAPIException
except:
    from api import pyCryptomusAPI, pyCryptomusAPIException

try:
    from private_keys import *
except:
    test_merchant_uuid = "---"
    test_api_token_payment = "---"
    test_api_token_payout = "---"

def run_and_print(f):
    try:
        sleep(1)
        print()
        print(inspect.getsourcelines(f)[0][0].strip())
        res = f()
        if isinstance(res, list):
            for i in res:
                print(i)
        else:
            print(res)
        return res
    except pyCryptomusAPIException as pe:
        if pe.code in [-2]:
            print("API call failed. Code: {}, Message: {}".format(pe.code, pe.message))
        else:
            print("API call failed. Code: {}, Message: {}".format(pe.code, pe.message))
            #raise pe
    except Exception as e:
        raise e
    return None

def test_api_functions():
    client = pyCryptomusAPI(
        test_merchant_uuid,
        payment_api_key=test_api_token_payment,
        payout_api_key=test_api_token_payout,
    print_errors=True)
    invoice = run_and_print(lambda: client.create_invoice(1, "USDT", str(uuid.uuid4())))
    invoice_uuid = invoice.uuid if invoice else "123"
    wallet = run_and_print(lambda: client.create_wallet("TRON", "TRX", str(uuid.uuid4())))
    wallet_uuid = wallet.uuid if wallet else "123"
    wallet_adress = wallet.address if wallet else "123"
    run_and_print(lambda: client.block_wallet(wallet_uuid = wallet_uuid))                        # Server error (reason unknown)
    run_and_print(lambda: client.block_wallet_refund(wallet_adress, wallet_uuid = wallet_uuid))  # Server error (it's ok)
    run_and_print(lambda: client.payment_information(invoice_uuid = invoice_uuid))
    run_and_print(lambda: client.refund(wallet_adress, True, invoice_uuid = invoice_uuid))       # Server error (looks ok)
    run_and_print(lambda: client.payment_services())
    run_and_print(lambda: client.payment_history())
    run_and_print(lambda: client.payment_history_filtered(is_final=True))
    run_and_print(lambda: client.payout_services())
    run_and_print(lambda: client.balance())

test_api_functions()



import json
from abc import ABC


class Dictionaryable(ABC):
    """
    (c) Based on pyTelegramBotAPI (https://github.com/eternnoir/pyTelegramBotAPI) Dictionaryable
    Subclasses of this class are guaranteed to be able to be converted to dictionary.
    All subclasses of this class must override to_dict.
    """

    def to_dict(self):
        """
        Returns a DICT with class field values
        This function must be overridden by subclasses.

        :return: a DICT
        """
        raise NotImplementedError


class JsonSerializable(ABC):
    """
    (c) Based on pyTelegramBotAPI (https://github.com/eternnoir/pyTelegramBotAPI) JsonSerializable
    Subclasses of this class are guaranteed to be able to be converted to JSON format.
    All subclasses of this class must override to_json.
    """

    def to_json(self):
        """
        Returns a JSON string representation of this class.
        This function must be overridden by subclasses.

        :return: a JSON formatted string.
        """
        raise NotImplementedError


class JsonDeserializable(ABC):
    """
    (c) Based on pyTelegramBotAPI (https://github.com/eternnoir/pyTelegramBotAPI) JsonDeserializable
    Subclasses of this class are guaranteed to be able to be created from a json-style dict or json formatted string.
    All subclasses of this class must override de_json.
    """

    @classmethod
    def de_json(cls, json_dict, process_mode = 0):
        """
        Returns an instance of this class from the given json dict or string.
        This function must be overridden by subclasses.

        :param json_dict: The json dict from which to create the object.
        :param process_mode: 0 - do nothing, 1 - create class instance, 2 - create class instance and fill fields

        :return: an instance of this class created from the given json dict or string.
        """
        if process_mode == 0:
            return None
        instance = cls()
        if process_mode == 2:
            for key, value in json_dict.items():
                setattr(instance, key, value)
        return instance

    @staticmethod
    def check_json(input_json, dict_copy=False):
        """
        Checks whether input_json is a dict or a string. If it is already a dict, it is returned as-is.
        If it is not, it is converted to a dict by means of json.loads(json_type)

        :param input_json: input json or parsed dict
        :param dict_copy: if dict is passed and it is changed outside
        :return: Dictionary parsed from json or original dict
        """
        if isinstance(input_json, dict):
            return input_json.copy() if dict_copy else input_json
        elif isinstance(input_json, str):
            return json.loads(input_json)
        else:
            raise ValueError("input_json should be a json dict or string.")

    def __str__(self):
        # d = {
        #     x: y.__dict__ if hasattr(y, '__dict__') else y
        #     for x, y in self.__dict__.items()
        # }
        d = {}
        for x, y in self.__dict__.items():
            if isinstance(y, list):
                d[x] = [str(i) for i in y]
            elif isinstance(y, dict):
                d[x] = {k:str(v) for k, v in y.items()}
            elif hasattr(y, '__dict__'):
                d[x] = y.__dict__
            else:
                d[x] = y
        return str(d)


# noinspection PyMethodOverriding
class BalanceItem(JsonDeserializable):
    def __init__(self):
        self.uuid = None
        self.balance = None
        self.currency_code = None

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(BalanceItem, cls).de_json(data, process_mode=2)
        instance.balance = float(instance.balance)
        instance.balance_usd = float(instance.balance_usd)
        return instance


# noinspection PyMethodOverriding
class Balance(JsonDeserializable):
    def __init__(self):
        self.merchant = []
        self.user = []

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(Balance, cls).de_json(data, process_mode=1)
        data = data.get("balance")
        if not data:
            raise ValueError("Not a balance")
        if "merchant" in data:
            for item in data["merchant"]:
                instance.merchant.append(BalanceItem.de_json(item))
        if "user" in data:
            for item in data["user"]:
                instance.user.append(BalanceItem.de_json(item))
        return instance


# noinspection PyMethodOverriding
class ServiceLimit(JsonDeserializable):
    def __init__(self):
        self.min_amount = None
        self.max_amount = None

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(ServiceLimit, cls).de_json(data, process_mode=2)
        instance.min_amount = float(instance.min_amount)
        instance.max_amount = float(instance.max_amount)
        return instance


# noinspection PyMethodOverriding
class ServiceCommission(JsonDeserializable):
    def __init__(self):
        self.fee_amount = None
        self.percent = None

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(ServiceCommission, cls).de_json(data, process_mode=2)
        instance.fee_amount = float(instance.fee_amount)
        instance.percent = float(instance.percent)
        return instance


# noinspection PyMethodOverriding
class Service(JsonDeserializable):
    def __init__(self):
        self.network = None
        self.currency = None
        self.is_available = None
        self.limit = None
        self.commission = None

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(Service, cls).de_json(data, process_mode=2)
        instance.limit = ServiceLimit.de_json(instance.limit)
        instance.commission = ServiceCommission.de_json(instance.commission)
        return instance


# noinspection PyMethodOverriding
class Currency(Dictionaryable, JsonDeserializable):
    """
    Class representing a currency
    """

    def __init__(self, currency, network = None):
        """
        :param currency: (String) currency code
        :param network: (String, Optional) network code
        """
        self.currency = currency
        self.network = network

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(Currency, cls).de_json(data, process_mode=2)
        return instance

    def to_dict(self):
        data = {
            "currency": self.currency,
            "network": self.network,
        }
        return data

# noinspection PyMethodOverriding
class Invoice(JsonDeserializable):
    def __init__(self):
        self.uuid = None
        self.order_id = None
        self.amount = None
        self.payment_amount = None
        self.payer_amount = None
        self.payer_currency = None
        self.currency = None
        self.comments = None
        self.network = None
        self.address = None
        self.from_ = None
        self.txid = None
        self.url = None
        self.expired_at = None
        self.payment_status = None
        self.is_final = None
        self.additional_data = None
        self.currencies = None

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(Invoice, cls).de_json(data, process_mode=2)
        if instance.amount is not None:
            instance.amount = float(instance.amount)
        if instance.payment_amount is not None:
            instance.payment_amount = float(instance.payment_amount)
        if instance.payer_amount is not None:
            instance.payer_amount = float(instance.payer_amount)
        if instance.expired_at is not None:
            instance.expired_at = int(instance.expired_at)
        if instance.currencies:
            instance.currencies = [Currency.de_json(i) for i in instance.currencies]
        return instance

# noinspection PyMethodOverriding
class Wallet(JsonDeserializable):
    def __init__(self):
        self.wallet_uuid = None
        self.uuid = None
        self.address = None
        self.network = None
        self.currency = None

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(Wallet, cls).de_json(data, process_mode=2)
        return instance

# noinspection PyMethodOverriding
class PaymentPaginate(JsonDeserializable):
    def __init__(self):
        self.count = None
        self.hasPages = None
        self.nextCursor = None
        self.previousCursor = None
        self.perPage = None

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(PaymentPaginate, cls).de_json(data, process_mode=2)
        instance.count = int(instance.count)
        instance.perPage = int(instance.perPage)
        return instance

# noinspection PyMethodOverriding
class PaymentsHistory(JsonDeserializable):
    def __init__(self):
        self.items = []
        self.paginate = PaymentPaginate()

    @classmethod
    def de_json(cls, json_dict):
        data = cls.check_json(json_dict)
        instance = super(PaymentsHistory, cls).de_json(data, process_mode=2)
        instance.items = [Invoice.de_json(i) for i in instance.items]
        instance.paginate = PaymentPaginate.de_json(instance.paginate)
        return instance



from hashlib import md5
import base64
import requests

from .cryto_types import *

API_URL = "https://api.cryptomus.com/v1/"


# noinspection PyPep8Naming
class pyCryptomusAPIException(Exception):
    def __init__(self, code, message, full_error = ""):
        self.code = code
        self.message = message
        self.full_error = full_error
        super().__init__(self.message)


# noinspection PyPep8Naming
class pyCryptomusAPI:
    """
    Cryptomus API Client
    """

    def __init__(self,
                 merchant_uuid, payment_api_key = None, payout_api_key = None,
                 print_errors = False, timeout = None):
        """
        Create the pyCryptomusAPI instance.

        :param merchant_uuid: The merchant's uuid, which you can find in the merchant's personal account in the settings section.
        :param payment_api_key: API key for processing payments
        :param payout_api_key: API key for accepting payment and making payouts
        :param print_errors: (Optional) Print dumps on request errors
        :param timeout: (Optional) Request timeout
        """
        self.merchant_uuid = merchant_uuid
        self.payment_api_key = payment_api_key
        self.payout_api_key = payout_api_key
        self.print_errors = print_errors
        self.timeout = timeout
        if not(self.payment_api_key) and not(self.payout_api_key):
            raise Exception("You must specify at least one API key.")

    def __request(self, method_url, mode, **kwargs):
        """
        Send request to API

        :param method_url: (String) API method url (part)
        :param mode: (Int) Method mode (1: payment, 2: payout)
        :param kwargs: request data
        """
        if kwargs:
            data = dict(kwargs)
        else:
            data = {}

        base_resp = None
        try:
            key = self.payment_api_key if (mode == 1) else self.payout_api_key
            json_dumps = json.dumps(data)
            # json_dumps = json.dumps(data, ensure_ascii=False, separators=(',', ':'))
            pre_sign = json_dumps if data else ""
            sign = md5(base64.b64encode(pre_sign.encode('ascii')) + key.encode('ascii')).hexdigest()
            # sign = md5(base64.encodebytes(pre_sign.encode('utf-8')) + key.encode('utf-8')).hexdigest()
            headers = {
                "merchant": self.merchant_uuid,
                "sign": sign,
                "Content-Type": "application/json",
            }
            # resp = requests.post(ENDPOINT + url, data=data, headers=headers, timeout=self.timeout).json()
            base_resp = requests.post(API_URL + method_url, data=pre_sign, headers=headers, timeout=self.timeout)
            resp = base_resp.json()
        except ValueError as ve:
            code = base_resp.status_code if base_resp else -2
            message = "Response decode failed: {}".format(ve)
            if self.print_errors:
                print(message)
            raise pyCryptomusAPIException(code, message)
        except Exception as e:
            code = base_resp.status_code if base_resp else -3
            message = "Request unknown exception: {}".format(e)
            if self.print_errors:
                print(message)
            raise pyCryptomusAPIException(code, message)
        if not resp:
            code = base_resp.status_code if base_resp else -4
            message = "None request response"
            if self.print_errors:
                print(message)
            raise pyCryptomusAPIException(code, message)
        elif not resp.get("result"):
            code = base_resp.status_code if base_resp else -5
            if resp.get("message"):
                message = resp["message"]
            elif resp.get("errors"):
                message = resp["errors"]
            else:
                message = "No error info provided"
            if self.print_errors:
                print("Response: {}".format(resp))
            raise pyCryptomusAPIException(code, message)
        else:
            return resp

    def create_invoice(self,
           amount, currency, order_id, network = None, url_return = None, url_callback = None,
           is_payment_multiple = None, lifetime = None, to_currency = None, subtract = None,
           accuracy_payment_percent = None, additional_data = None, currencies = None,
           except_currencies = None):
        """
        Creating an invoice
        https://doc.cryptomus.com/payments/creating-invoice
        Requires PAYMENT API key

        amount: (Float) The amount of the invoice
        currency: (String) Currency code (https://doc.cryptomus.com/reference)
        order_id: (String) Order ID in your system
        network: (String, Optional) Blockchain network code (https://doc.cryptomus.com/reference)
        url_return: (String, Optional) Url to which the user will return after payment
        url_callback: (String, Optional) Url to which webhooks with payment status will be sent
        is_payment_multiple: (Bool, Optional) Whether payment of the remaining amount is possible (true/false)
        lifetime: (?Int?, Optional) The lifespan of the issued invoice (?in seconds?)
        to_currency: (String, Optional) Currency code for accepting payments
        subtract: (?Float?, Optional) Percentage of the payment commission charged to the client. The subtract parameter allows you to specify what percentage of the payment acceptance will be paid by the client. If you have a payment commission 1%, then if you create an invoice for 100 USDT with subtract=100 (the client pays 100% commission), the client will have to pay 101 USDT.
        accuracy_payment_percent: (?Float?, Optional) Acceptable inaccuracy in payment (min 0, max 5.00)
        additional_data: (?String?, Optional) Additional information
        currencies: (List[Currency], Optional) List of allowed currencies for payment Structure
        except_currencies: (List[Currency], Optional) List of excluded currencies for payment Structure
        """
        method = "payment"
        params = {
            "amount": str(amount),
            "currency": currency,
            "order_id": str(order_id),
        }
        if network:
            params["network"] = network
        if url_return:
            params["url_return"] = url_return
        if url_callback:
            params["url_callback"] = url_callback
        if is_payment_multiple is not None:
            params["is_payment_multiple"] = is_payment_multiple
        if lifetime is not None:
            params["lifetime"] = str(lifetime)
        if to_currency:
            params["to_currency"] = to_currency
        if subtract is not None:
            params["subtract"] = str(subtract)
        if accuracy_payment_percent is not None:
            params["accuracy_payment_percent"] = str(accuracy_payment_percent)
        if additional_data:
            params["additional_data"] = additional_data
        if currencies:
            params["currencies"] = [i.to_dict() for i in currencies]
        if except_currencies:
            params["except_currencies"] = [i.to_dict() for i in except_currencies]
        resp = self.__request(method, 1, **params).get("result")
        return Invoice.de_json(resp)

    def create_wallet(self,
           network, currency, order_id, url_callback = None):
        """
        Creating a Static wallet
        https://doc.cryptomus.com/payments/creating-static
        Requires PAYMENT API key

        network: (String) Blockchain network code (https://doc.cryptomus.com/reference)
        currency: (String) Currency code (https://doc.cryptomus.com/reference)
        order_id: (String) Order ID in your system
        url_callback: (String, Optional) Url to which webhooks with payment status will be sent
        """
        method = "wallet"
        params = {
            "network": network,
            "currency": currency,
            "order_id": str(order_id),
        }
        if url_callback:
            params["url_callback"] = url_callback
        resp = self.__request(method, 1, **params).get("result")
        return Wallet.de_json(resp)

    def block_wallet(self,
           wallet_uuid = None, order_id = None, is_force_refund = None):
        """
        Block static wallet
        https://doc.cryptomus.com/payments/block-wallet
        You need to pass one of the required parameters, if you pass both, the account will be identified by order_id
        Requires PAYMENT API key

        wallet_uuid: (String, Optional if order_id set) Wallet UUID
        order_id: (String, Optional if wallet_uuid set) Order ID in your system
        is_force_refund: (Bool, Optional) Refund all incoming payments to sender’s address
        """
        method = "wallet/block-address"
        params = {
        }
        if not(wallet_uuid) and not(order_id):
            raise pyCryptomusAPIException(0, "You need to pass one of the required parameters")
        if wallet_uuid:
            params["uuid"] = wallet_uuid
        if order_id:
            params["order_id"] = order_id
        if is_force_refund is not None:
            params["is_force_refund"] = is_force_refund
        resp = self.__request(method, 1, **params).get("result")
        return resp

    def block_wallet_refund(self,
           address, wallet_uuid = None, order_id = None):
        """
        Refund payments on blocked address
        https://doc.cryptomus.com/payments/refundblocked
        You need to pass one of the required parameters, if you pass both, the account will be identified by order_id
        Requires PAYMENT API key

        address: (String) Address (wallet addres? refund address?)
        wallet_uuid: (String, Optional if order_id set) Wallet UUID
        order_id: (String, Optional if wallet_uuid set) Order ID in your system
        """
        method = "wallet/blocked-address-refund"
        params = {
            "address": address,
        }
        if not(wallet_uuid) and not(order_id):
            raise pyCryptomusAPIException(0, "You need to pass one of the required parameters")
        if wallet_uuid:
            params["uuid"] = wallet_uuid
        if order_id:
            params["order_id"] = order_id
        resp = self.__request(method, 1, **params).get("result")
        return resp

    def payment_information(self,
           invoice_uuid = None, order_id = None):
        """
        Payment information
        https://doc.cryptomus.com/payments/payment-information
        You need to pass one of the required parameters, if you pass both, the account will be identified by order_id
        Requires PAYMENT API key

        invoice_uuid: (String, Optional if order_id set) Invoice UUID
        order_id: (String, Optional if wallet_uuid set) Order ID in your system
        """
        method = "payment/info"
        params = {
        }
        if not(invoice_uuid) and not(order_id):
            raise pyCryptomusAPIException(0, "You need to pass one of the required parameters")
        if invoice_uuid:
            params["uuid"] = invoice_uuid
        if order_id:
            params["order_id"] = order_id
        resp = self.__request(method, 1, **params).get("result")
        return Invoice.de_json(resp)

    def refund(self,
           address, is_subtract, invoice_uuid = None, order_id = None):
        """
        Refund
        https://doc.cryptomus.com/payments/refund
        You need to pass one of the required parameters, if you pass both, the account will be identified by invoice_uuid
        Requires PAYMENT API key

        address: (String) Refund address
        is_subtract: (Bool) Determines whether the commission is to be charged to the merchant or to the client (True - to the merchant, False - to the client)
        invoice_uuid: (String, Optional if order_id set) Invoice UUID
        order_id: (String, Optional if wallet_uuid set) Order ID in your system
        """
        method = "payment/refund"
        params = {
            "address": address,
            "is_subtract": is_subtract,
        }
        if not(invoice_uuid) and not(order_id):
            raise pyCryptomusAPIException(0, "You need to pass one of the required parameters")
        if invoice_uuid:
            params["uuid"] = invoice_uuid
        if order_id:
            params["order_id"] = order_id
        resp = self.__request(method, 1, **params).get("result")
        return Invoice.de_json(resp)

    def payment_history(self, cursor = None):
        """
        Payment history
        https://doc.cryptomus.com/payments/payment-history
        Requires PAYMENT API key

        cursor: (String, Optional) Page cursor (hash)
        """
        params = {
        }
        if cursor:
            params["cursor"] = cursor
        method = "payment/list"
        if params:
            resp = self.__request(method, 1, **params).get("result")
        else:
            resp = self.__request(method, 1).get("result")
        return PaymentsHistory.de_json(resp)

    def payment_history_filtered(
            self, max_results = 15, max_pages = 10,
            currencies = None, networks = None, addresses = None,
            statuses = None, is_final = None):
        """
        Payment history (advanced mode)

        Based on: payment_history
        https://doc.cryptomus.com/payments/payment-history
        Requires PAYMENT API key

        Collects only results under filters.
        Process as many pages as needed to collect max_results, but not more than max_pages.

        max_results: (Int) Max number of results to collect
        max_pages: (Int, Optional, default=10) Max number of pages to process
        currencies: (List of Strings, Optional) List of accepted currencies. Codes: https://doc.cryptomus.com/reference
        networks: (List of Strings, Optional) List of accepted networks. Codes: https://doc.cryptomus.com/reference
        addresses: (List of Strings, Optional) List of accepted addresses
        statuses: (List of Strings, Optional) List of accepted statuses. Codes: https://doc.cryptomus.com/payments/payment-statuses
        is_final: (Bool, Optional) If True, only final payments will be collected, if False - only non-final
        """

        result = PaymentsHistory()

        page_number = 0
        cursor = None
        while page_number < max_pages:
            resp = self.payment_history(cursor = cursor)

            if not resp.items:
                # No (more) payments
                break

            for payment in resp.items:
                if currencies and not(payment.currency in currencies):
                    continue
                if networks and not(payment.network in networks):
                    continue
                if addresses and not(payment.address in addresses):
                    continue
                if statuses and not(payment.status in statuses):
                    continue
                if (is_final is not None) and payment.is_final != is_final:
                    continue
                result.items.append(payment)

                if len(result.items) >= max_results:
                    # Enough results collected
                    break

            cursor = resp.paginate.nextCursor
            if not cursor:
                # No more pages
                break
            page_number += 1

        return result

    def payment_services(self):
        """
        Get collection of all available payment services
        https://doc.cryptomus.com/payments/list-of-services
        Requires PAYMENT API key
        """
        method = "payment/services"
        resp = self.__request(method, 1).get("result")
        return [Service.de_json(i) for i in resp]

    def payout_services(self):
        """
        Get collection of all available payout services
        https://doc.cryptomus.com/payouts/list-of-services
        Requires PAYMOUT API key
        """
        method = "payout/services"
        resp = self.__request(method, 2).get("result")
        return [Service.de_json(i) for i in resp]

    def balance(self):
        """
        Get balance of merchant(account) or user(wallet)
        https://doc.cryptomus.com/balance
        Requires PAYMENT API key
        """
        method = "balance"
        resp = self.__request(method, 1).get("result")
        return Balance.de_json(resp[0])



test_merchant_uuid = "ded91cc8-9e8d-44f6-925d-7188dac90de4"
test_api_token_payment = "RXCBB3ir4xLe8tmzQySBIeyJmkEd7SjbZpFPcm2s6fXigdEejNPKZBIPK6amjxCKFLrqduPjnaqZbneSD0A8idfLibMGkjTUyIcEYnMKEmqB5poW4cdm6nFKWZzKXrP8"
test_api_token_payout = "GzFfltvoDP5Vb4BQjTsUb6BTr9uJRDFIaScOy8W6zlAQTpDOYzcxck1DcXca2NPFvqae4Wfip0KyMUp2DkCLBKjc0HS2C88mtTwxikeADpKpYVMvHeyG63tdgeLChO8h"



#!/usr/bin/env python
from setuptools import setup
from io import open
import re

def read(filename):
    with open(filename, encoding='utf-8') as file:
        return file.read()

with open('pyCryptomusAPI/version.py', 'r', encoding='utf-8') as f:  # Credits: LonamiWebs
    version = re.search(r"^__version__\s*=\s*'(.*)'.*$",
                        f.read(), flags=re.MULTILINE).group(1)

setup(name='pyCryptomusAPI',
      version=version,
      description='Python implementation of Cryptomus (https://cryptomus.com) pubilc API',
      long_description=read('README.md'),
      long_description_content_type="text/markdown",
      author='Badiboy',
      url='https://github.com/Badiboy/pyCryptomusAPI',
      packages=['pyCryptomusAPI'],
      requires=['requests'],
      license='MIT license',
      keywords="Crypto Pay API Cryptomus",
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Programming Language :: Python :: 3',
          'License :: OSI Approved :: MIT License',
      ],
)
